# Lambdapdk Introduction

The Lambdapdk project includes a number of open source Process Design Kits (PDKs). The original source of these PDKs is documented in the README file for each PDK. Cell level mapping is included to the generic technology independent [Lambdalib](https://github.com/siliconcompiler/lambdalib) library.

Lambdapdk is supported by the [SiliconCompiler](https://github.com/siliconcompiler/siliconcompiler) project.


Supported PDKs:

* [ASAP7](lambdapdk/asap7/README.md)
* [FreePDK45](lambdapdk/freepdk45/base/README.md)
* [Skywater130](lambdapdk/sky130/base/README.md)
* [Global Foundries 180](lambdapdk/gf180/README.md)

# License

[Apache License 2.0](LICENSE)

Specific PDK licences can be found in their respective folders.

# Issues / Bugs

We use [GitHub Issues](https://github.com/siliconcompiler/lambdapdk/issues)
for tracking requests and bugs.
